from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKTransition(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKTransitionDirectionUp, 0)
        self.assertEqual(SpriteKit.SKTransitionDirectionDown, 1)
        self.assertEqual(SpriteKit.SKTransitionDirectionRight, 2)
        self.assertEqual(SpriteKit.SKTransitionDirectionLeft, 3)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertArgIsBOOL(SpriteKit.SKTransition.setPausesIncomingScene_, 0)
        self.assertResultIsBOOL(SpriteKit.SKTransition.pausesIncomingScene)
        self.assertArgIsBOOL(SpriteKit.SKTransition.setPausesOutgoingScene_, 0)
        self.assertResultIsBOOL(SpriteKit.SKTransition.pausesOutgoingScene)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKPhysicsJoint(TestCase):
    @min_os_level("10.9")
    def testMethods(self):
        self.assertArgIsBOOL(SpriteKit.SKPhysicsJointPin.setShouldEnableLimits_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsJointPin.shouldEnableLimits)

        self.assertArgIsBOOL(SpriteKit.SKPhysicsJointSliding.setShouldEnableLimits_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsJointSliding.shouldEnableLimits)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import SpriteKit


class TestSK3Node(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(SpriteKit.SK3DNode, objc.objc_class)

        self.assertResultIsBOOL(SpriteKit.SK3DNode.isPlaying)
        self.assertArgIsBOOL(SpriteKit.SK3DNode.setPlaying_, 0)

        self.assertResultIsBOOL(SpriteKit.SK3DNode.loops)
        self.assertArgIsBOOL(SpriteKit.SK3DNode.setLoops_, 0)

        self.assertResultIsBOOL(SpriteKit.SK3DNode.autoenablesDefaultLighting)
        self.assertArgIsBOOL(SpriteKit.SK3DNode.setAutoenablesDefaultLighting_, 0)

        node = SpriteKit.SK3DNode.alloc().initWithViewportSize_((100, 200))
        v = node.projectPoint_((10, 20, 30))
        self.assertIsInstance(v, tuple)
        self.assertEqual(len(v), 3)
        self.assertTrue(all(isinstance(i, float) for i in v))

        v = node.unprojectPoint_((10, 20, 30))
        self.assertIsInstance(v, tuple)
        self.assertEqual(len(v), 3)
        self.assertTrue(all(isinstance(i, float) for i in v))



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import SpriteKit


class TestSKScene(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKSceneScaleModeFill, 0)
        self.assertEqual(SpriteKit.SKSceneScaleModeAspectFill, 1)
        self.assertEqual(SpriteKit.SKSceneScaleModeAspectFit, 2)
        self.assertEqual(SpriteKit.SKSceneScaleModeResizeFill, 3)

    @min_os_level("10.10")
    def testProtocols(self):
        objc.protocolNamed("SKSceneDelegate")



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKTextureAtlas(TestCase):
    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertArgIsBlock(
            SpriteKit.SKTextureAtlas.preloadTextureAtlases_withCompletionHandler_,
            1,
            b"v",
        )
        self.assertArgIsBlock(
            SpriteKit.SKTextureAtlas.preloadWithCompletionHandler_, 0, b"v"
        )



"""
Python mapping for the SpriteKit framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Cocoa
import objc
import Quartz
from SpriteKit import _metadata, _SpriteKit

sys.modules["SpriteKit"] = mod = objc.ObjCLazyModule(
    "SpriteKit",
    "com.apple.SpriteKit",
    objc.pathForFramework("/System/Library/Frameworks/SpriteKit.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_SpriteKit, Cocoa, Quartz),
)


mod = sys.modules["SpriteKit"]
del sys.modules["SpriteKit._metadata"]



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKSpriteNode(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBOOL(
            SpriteKit.SKSpriteNode.spriteNodeWithImageNamed_normalMapped_, 1
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKTileSet(TestCase):
    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKTileSetTypeGrid, 0)
        self.assertEqual(SpriteKit.SKTileSetTypeIsometric, 1)
        self.assertEqual(SpriteKit.SKTileSetTypeHexagonalFlat, 2)
        self.assertEqual(SpriteKit.SKTileSetTypeHexagonalPointy, 3)
        self.assertEqual(SpriteKit.SKTileAdjacencyUp, 1 << 0)
        self.assertEqual(SpriteKit.SKTileAdjacencyUpperRight, 1 << 1)
        self.assertEqual(SpriteKit.SKTileAdjacencyRight, 1 << 2)
        self.assertEqual(SpriteKit.SKTileAdjacencyLowerRight, 1 << 3)
        self.assertEqual(SpriteKit.SKTileAdjacencyDown, 1 << 4)
        self.assertEqual(SpriteKit.SKTileAdjacencyLowerLeft, 1 << 5)
        self.assertEqual(SpriteKit.SKTileAdjacencyLeft, 1 << 6)
        self.assertEqual(SpriteKit.SKTileAdjacencyUpperLeft, 1 << 7)
        self.assertEqual(
            SpriteKit.SKTileAdjacencyAll,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft,
        )
        self.assertEqual(SpriteKit.SKTileHexFlatAdjacencyUp, 1 << 0)
        self.assertEqual(SpriteKit.SKTileHexFlatAdjacencyUpperRight, 1 << 1)
        self.assertEqual(SpriteKit.SKTileHexFlatAdjacencyLowerRight, 1 << 2)
        self.assertEqual(SpriteKit.SKTileHexFlatAdjacencyDown, 1 << 3)
        self.assertEqual(SpriteKit.SKTileHexFlatAdjacencyLowerLeft, 1 << 4)
        self.assertEqual(SpriteKit.SKTileHexFlatAdjacencyUpperLeft, 1 << 5)
        self.assertEqual(
            SpriteKit.SKTileHexFlatAdjacencyAll,
            SpriteKit.SKTileHexFlatAdjacencyUp
            | SpriteKit.SKTileHexFlatAdjacencyUpperRight
            | SpriteKit.SKTileHexFlatAdjacencyLowerRight
            | SpriteKit.SKTileHexFlatAdjacencyDown
            | SpriteKit.SKTileHexFlatAdjacencyLowerLeft
            | SpriteKit.SKTileHexFlatAdjacencyUpperLeft,
        )
        self.assertEqual(SpriteKit.SKTileHexPointyAdjacencyUpperLeft, 1 << 0)
        self.assertEqual(SpriteKit.SKTileHexPointyAdjacencyUpperRight, 1 << 1)
        self.assertEqual(SpriteKit.SKTileHexPointyAdjacencyRight, 1 << 2)
        self.assertEqual(SpriteKit.SKTileHexPointyAdjacencyLowerRight, 1 << 3)
        self.assertEqual(SpriteKit.SKTileHexPointyAdjacencyLowerLeft, 1 << 4)
        self.assertEqual(SpriteKit.SKTileHexPointyAdjacencyLeft, 1 << 5)
        self.assertEqual(
            SpriteKit.SKTileHexPointyAdjacencyAdd,
            SpriteKit.SKTileHexPointyAdjacencyUpperLeft
            | SpriteKit.SKTileHexPointyAdjacencyUpperRight
            | SpriteKit.SKTileHexPointyAdjacencyRight
            | SpriteKit.SKTileHexPointyAdjacencyLowerRight
            | SpriteKit.SKTileHexPointyAdjacencyLowerLeft
            | SpriteKit.SKTileHexPointyAdjacencyLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyUpEdge,
            SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyUpperRightEdge,
            SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyRightEdge,
            SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft
            | SpriteKit.SKTileAdjacencyUp,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyLowerRightEdge,
            SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft
            | SpriteKit.SKTileAdjacencyUp,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyDownEdge,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyLowerLeftEdge,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyLeftEdge,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyUpperLeftEdge,
            SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyUpperRightCorner,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyLowerRightCorner,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyLowerLeftCorner,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyLowerRight
            | SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft,
        )
        self.assertEqual(
            SpriteKit.SKTileAdjacencyUpperLeftCorner,
            SpriteKit.SKTileAdjacencyUp
            | SpriteKit.SKTileAdjacencyUpperRight
            | SpriteKit.SKTileAdjacencyRight
            | SpriteKit.SKTileAdjacencyDown
            | SpriteKit.SKTileAdjacencyLowerLeft
            | SpriteKit.SKTileAdjacencyLeft
            | SpriteKit.SKTileAdjacencyUpperLeft,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKKeyframeSequence(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKInterpolationModeLinear, 1)
        self.assertEqual(SpriteKit.SKInterpolationModeSpline, 2)
        self.assertEqual(SpriteKit.SKInterpolationModeStep, 3)

        self.assertEqual(SpriteKit.SKRepeatModeClamp, 1)
        self.assertEqual(SpriteKit.SKRepeatModeLoop, 2)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKRenderer(TestCase):
    @min_os_level("10.13")
    def testMethods(self):
        self.assertResultIsBOOL(SpriteKit.SKRenderer.ignoresSiblingOrder)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setIgnoresSiblingOrder_, 0)

        self.assertResultIsBOOL(SpriteKit.SKRenderer.shouldCullNonVisibleNodes)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setShouldCullNonVisibleNodes_, 0)

        self.assertResultIsBOOL(SpriteKit.SKRenderer.showsDrawCount)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setShowsDrawCount_, 0)

        self.assertResultIsBOOL(SpriteKit.SKRenderer.showsNodeCount)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setShowsNodeCount_, 0)

        self.assertResultIsBOOL(SpriteKit.SKRenderer.showsQuadCount)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setShowsQuadCount_, 0)

        self.assertResultIsBOOL(SpriteKit.SKRenderer.showsPhysics)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setShowsPhysics_, 0)

        self.assertResultIsBOOL(SpriteKit.SKRenderer.showsFields)
        self.assertArgIsBOOL(SpriteKit.SKRenderer.setShowsFields_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKKeyframeSequence(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKLabelVerticalAlignmentModeBaseline, 0)
        self.assertEqual(SpriteKit.SKLabelVerticalAlignmentModeCenter, 1)
        self.assertEqual(SpriteKit.SKLabelVerticalAlignmentModeTop, 2)
        self.assertEqual(SpriteKit.SKLabelVerticalAlignmentModeBottom, 3)

        self.assertEqual(SpriteKit.SKLabelHorizontalAlignmentModeCenter, 0)
        self.assertEqual(SpriteKit.SKLabelHorizontalAlignmentModeLeft, 1)
        self.assertEqual(SpriteKit.SKLabelHorizontalAlignmentModeRight, 2)



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit
import Quartz


class TestSKPhysicsWorld(TestCase):
    @min_os_level("10.9")
    def testMethods(self):
        self.assertArgIsBlock(
            SpriteKit.SKPhysicsWorld.enumerateBodiesAtPoint_usingBlock_, 1, b"v@o^Z"
        )
        self.assertArgIsBlock(
            SpriteKit.SKPhysicsWorld.enumerateBodiesInRect_usingBlock_, 1, b"v@o^Z"
        )
        self.assertArgIsBlock(
            SpriteKit.SKPhysicsWorld.enumerateBodiesAlongRayStart_end_usingBlock_,
            2,
            b"v@" + Quartz.CGPoint.__typestr__ + Quartz.CGVector.__typestr__ + b"o^Z",
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        o = SpriteKit.SKPhysicsWorld.alloc().init()
        v = o.sampleFieldsAt_((9, 10, 11))
        self.assertIsInstance(v, tuple)
        self.assertEqual(len(v), 3)
        self.assertIsInstance(v[0], float)
        self.assertIsInstance(v[1], float)
        self.assertIsInstance(v[2], float)

    @min_os_level("10.10")
    def testProtocols(self):
        objc.protocolNamed("SKPhysicsContactDelegate")



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit
import objc


class TestSKMutableTexture(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBlock(
            SpriteKit.SKMutableTexture.modifyPixelDataWithBlock_,
            0,
            b"vN^v" + objc._C_NSUInteger,
        )



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level

import SpriteKit


class TestSKViewHelper(SpriteKit.NSObject):
    def view_shouldRenderAtTime_(self, v, t):
        return 1


class TestSKView(TestCase):
    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertArgIsBOOL(SpriteKit.SKView.setPaused_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.isPaused)
        self.assertArgIsBOOL(SpriteKit.SKView.setShowsFPS_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.showsFPS)
        self.assertArgIsBOOL(SpriteKit.SKView.setShowsDrawCount_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.showsDrawCount)
        self.assertArgIsBOOL(SpriteKit.SKView.setShowsNodeCount_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.showsNodeCount)

        self.assertArgIsBOOL(SpriteKit.SKView.setAsynchronous_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.isAsynchronous)
        self.assertArgIsBOOL(SpriteKit.SKView.setIgnoresSiblingOrder_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.ignoresSiblingOrder)

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBOOL(SpriteKit.SKView.setShowsFields_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.showsFields)
        self.assertArgIsBOOL(SpriteKit.SKView.setShowsPhysics_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.showsPhysics)
        self.assertArgIsBOOL(SpriteKit.SKView.setShowsQuadCount_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.showsQuadCount)
        self.assertArgIsBOOL(SpriteKit.SKView.setAllowsTransparency_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.allowsTransparency)
        self.assertArgIsBOOL(SpriteKit.SKView.setShouldCullNonVisibleNodes_, 0)
        self.assertResultIsBOOL(SpriteKit.SKView.shouldCullNonVisibleNodes)

    @min_os_level("10.16")
    def testMethods10_16(self):
        self.assertResultIsBOOL(SpriteKit.SKView.disableDepthStencilBuffer)

    @min_sdk_level("10.12")
    def testProtocols(self):
        objc.protocolNamed("SKViewDelegate")

        self.assertResultIsBOOL(TestSKViewHelper.view_shouldRenderAtTime_)
        self.assertArgHasType(TestSKViewHelper.view_shouldRenderAtTime_, 1, objc._C_DBL)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKNode_NSAccessibility(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertResultIsBOOL(SpriteKit.SKNode.isAccessibilityElement)
        self.assertArgIsBOOL(SpriteKit.SKNode.setAccessibilityElement_, 0)

        self.assertResultIsBOOL(SpriteKit.SKNode.isAccessibilityEnabled)
        self.assertArgIsBOOL(SpriteKit.SKNode.setAccessibilityEnabled_, 0)

        self.assertArgHasType(
            SpriteKit.SKNode.accessibilityHitTest_, 0, SpriteKit.CGPoint.__typestr__
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKShapeNode(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBOOL(SpriteKit.SKShapeNode.shapeNodeWithPath_centered_, 1)

        self.assertArgIsIn(SpriteKit.SKShapeNode.shapeNodeWithPoints_count_, 0)
        self.assertArgSizeInArg(SpriteKit.SKShapeNode.shapeNodeWithPoints_count_, 0, 1)
        self.assertArgIsIn(SpriteKit.SKShapeNode.shapeNodeWithSplinePoints_count_, 0)
        self.assertArgSizeInArg(
            SpriteKit.SKShapeNode.shapeNodeWithSplinePoints_count_, 0, 1
        )

        self.assertArgIsBOOL(SpriteKit.SKShapeNode.setAntialiased_, 0)
        self.assertResultIsBOOL(SpriteKit.SKShapeNode.isAntialiased)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKAction(TestCase):
    @min_os_level("10.10")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKUniformTypeNone, 0)
        self.assertEqual(SpriteKit.SKUniformTypeFloat, 1)
        self.assertEqual(SpriteKit.SKUniformTypeFloatVector2, 2)
        self.assertEqual(SpriteKit.SKUniformTypeFloatVector3, 3)
        self.assertEqual(SpriteKit.SKUniformTypeFloatVector4, 4)
        self.assertEqual(SpriteKit.SKUniformTypeFloatMatrix2, 5)
        self.assertEqual(SpriteKit.SKUniformTypeFloatMatrix3, 6)
        self.assertEqual(SpriteKit.SKUniformTypeFloatMatrix4, 7)
        self.assertEqual(SpriteKit.SKUniformTypeTexture, 8)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKTileDefinition(TestCase):
    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKTileDefinitionRotation0, 0)
        self.assertEqual(SpriteKit.SKTileDefinitionRotation90, 1)
        self.assertEqual(SpriteKit.SKTileDefinitionRotation180, 2)
        self.assertEqual(SpriteKit.SKTileDefinitionRotation270, 3)

    @min_os_level("10.12")
    def testMethods(self):
        self.assertResultIsBOOL(SpriteKit.SKTileDefinition.flipVertically)
        self.assertArgIsBOOL(SpriteKit.SKTileDefinition.setFlipVertically_, 0)

        self.assertResultIsBOOL(SpriteKit.SKTileDefinition.flipHorizontally)
        self.assertArgIsBOOL(SpriteKit.SKTileDefinition.setFlipHorizontally_, 0)



# This file is generated by objective.metadata
#
# Last update: Sun Jun 28 10:44:15 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$PHYSICSKIT_MINUS_GL_IMPORTS@1$SKActionTimingEaseIn@1$SKActionTimingEaseInEaseOut@3$SKActionTimingEaseOut@2$SKActionTimingLinear@0$SKAttributeTypeFloat@1$SKAttributeTypeHalfFloat@5$SKAttributeTypeNone@0$SKAttributeTypeVectorFloat2@2$SKAttributeTypeVectorFloat3@3$SKAttributeTypeVectorFloat4@4$SKAttributeTypeVectorHalfFloat2@6$SKAttributeTypeVectorHalfFloat3@7$SKAttributeTypeVectorHalfFloat4@8$SKBlendModeAdd@1$SKBlendModeAlpha@0$SKBlendModeMultiply@3$SKBlendModeMultiplyAlpha@7$SKBlendModeMultiplyX2@4$SKBlendModeReplace@6$SKBlendModeScreen@5$SKBlendModeSubtract@2$SKInterpolationModeLinear@1$SKInterpolationModeSpline@2$SKInterpolationModeStep@3$SKLabelHorizontalAlignmentModeCenter@0$SKLabelHorizontalAlignmentModeLeft@1$SKLabelHorizontalAlignmentModeRight@2$SKLabelVerticalAlignmentModeBaseline@0$SKLabelVerticalAlignmentModeBottom@3$SKLabelVerticalAlignmentModeCenter@1$SKLabelVerticalAlignmentModeTop@2$SKNodeFocusBehaviorFocusable@2$SKNodeFocusBehaviorNone@0$SKNodeFocusBehaviorOccluding@1$SKParticleRenderOrderDontCare@2$SKParticleRenderOrderOldestFirst@1$SKParticleRenderOrderOldestLast@0$SKRepeatModeClamp@1$SKRepeatModeLoop@2$SKSceneScaleModeAspectFill@1$SKSceneScaleModeAspectFit@2$SKSceneScaleModeFill@0$SKSceneScaleModeResizeFill@3$SKTextureFilteringLinear@1$SKTextureFilteringNearest@0$SKTileAdjacencyAll@255$SKTileAdjacencyDown@16$SKTileAdjacencyDownEdge@199$SKTileAdjacencyLeft@64$SKTileAdjacencyLeftEdge@31$SKTileAdjacencyLowerLeft@32$SKTileAdjacencyLowerLeftCorner@253$SKTileAdjacencyLowerLeftEdge@7$SKTileAdjacencyLowerRight@8$SKTileAdjacencyLowerRightCorner@127$SKTileAdjacencyLowerRightEdge@193$SKTileAdjacencyRight@4$SKTileAdjacencyRightEdge@241$SKTileAdjacencyUp@1$SKTileAdjacencyUpEdge@124$SKTileAdjacencyUpperLeft@128$SKTileAdjacencyUpperLeftCorner@247$SKTileAdjacencyUpperLeftEdge@28$SKTileAdjacencyUpperRight@2$SKTileAdjacencyUpperRightCorner@223$SKTileAdjacencyUpperRightEdge@112$SKTileDefinitionRotation0@0$SKTileDefinitionRotation180@2$SKTileDefinitionRotation270@3$SKTileDefinitionRotation90@1$SKTileHexFlatAdjacencyAll@63$SKTileHexFlatAdjacencyDown@8$SKTileHexFlatAdjacencyLowerLeft@16$SKTileHexFlatAdjacencyLowerRight@4$SKTileHexFlatAdjacencyUp@1$SKTileHexFlatAdjacencyUpperLeft@32$SKTileHexFlatAdjacencyUpperRight@2$SKTileHexPointyAdjacencyAdd@63$SKTileHexPointyAdjacencyLeft@32$SKTileHexPointyAdjacencyLowerLeft@16$SKTileHexPointyAdjacencyLowerRight@8$SKTileHexPointyAdjacencyRight@4$SKTileHexPointyAdjacencyUpperLeft@1$SKTileHexPointyAdjacencyUpperRight@2$SKTileSetTypeGrid@0$SKTileSetTypeHexagonalFlat@2$SKTileSetTypeHexagonalPointy@3$SKTileSetTypeIsometric@1$SKTransitionDirectionDown@1$SKTransitionDirectionLeft@3$SKTransitionDirectionRight@2$SKTransitionDirectionUp@0$SKUniformTypeFloat@1$SKUniformTypeFloatMatrix2@5$SKUniformTypeFloatMatrix3@6$SKUniformTypeFloatMatrix4@7$SKUniformTypeFloatVector2@2$SKUniformTypeFloatVector3@3$SKUniformTypeFloatVector4@4$SKUniformTypeNone@0$SKUniformTypeTexture@8$SKVIEW_AVAILABLE@1$SK_VERSION@39000000$"""
misc.update({})
aliases = {"SK_AVAILABLE": "__OSX_AVAILABLE_STARTING", "SKColor": "NSColor"}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"didApplyConstraintsForScene:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didBeginContact:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didEndContact:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didEvaluateActionsForScene:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didFinishUpdateForScene:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didSimulatePhysicsForScene:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setSubdivisionLevels:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"q"}}},
    )
    r(
        b"NSObject",
        b"setWarpGeometry:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"subdivisionLevels", {"required": True, "retval": {"type": b"q"}})
    r(
        b"NSObject",
        b"update:forScene:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"d"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"view:shouldRenderAtTime:",
        {
            "required": False,
            "retval": {"type": "Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "d"}},
        },
    )
    r(b"NSObject", b"warpGeometry", {"required": True, "retval": {"type": b"@"}})
    r(b"SK3DNode", b"autoenablesDefaultLighting", {"retval": {"type": b"Z"}})
    r(b"SK3DNode", b"isPlaying", {"retval": {"type": b"Z"}})
    r(b"SK3DNode", b"loops", {"retval": {"type": b"Z"}})
    r(
        b"SK3DNode",
        b"projectPoint:",
        {"retval": {"type": b"%"}, "arguments": {2: {"type": b"%"}}},
    )
    r(
        b"SK3DNode",
        b"setAutoenablesDefaultLighting:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"SK3DNode", b"setLoops:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SK3DNode", b"setPlaying:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SK3DNode",
        b"unprojectPoint:",
        {"retval": {"type": b"%"}, "arguments": {2: {"type": b"%"}}},
    )
    r(
        b"SKAction",
        b"animateWithNormalTextures:timePerFrame:resize:restore:",
        {"arguments": {4: {"type": b"Z"}, 5: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"animateWithTextures:timePerFrame:resize:restore:",
        {"arguments": {4: {"type": b"Z"}, 5: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"animateWithWarps:times:restore:",
        {"arguments": {4: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"customActionWithDuration:actionBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"f", b"d")},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SKAction",
        b"followPath:asOffset:orientToPath:duration:",
        {"arguments": {3: {"type": b"Z"}, 4: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"followPath:asOffset:orientToPath:speed:",
        {"arguments": {3: {"type": b"Z"}, 4: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"performSelector:onTarget:",
        {"arguments": {2: {"sel_of_type": b"v@:"}}},
    )
    r(
        b"SKAction",
        b"playSoundFileNamed:waitForCompletion:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"rotateToAngle:duration:shortestUnitArc:",
        {"arguments": {4: {"type": b"Z"}}},
    )
    r(
        b"SKAction",
        b"runBlock:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"SKAction",
        b"runBlock:queue:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"SKAction", b"setNormalTexture:resize:", {"arguments": {3: {"type": b"Z"}}})
    r(b"SKAction", b"setTexture:resize:", {"arguments": {3: {"type": b"Z"}}})
    r(
        b"SKAction",
        b"setTimingFunc:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"f"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"f"}},
                    }
                }
            }
        },
    )
    r(
        b"SKAction",
        b"setTimingFunction:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"f"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"f"}},
                    }
                }
            }
        },
    )
    r(
        b"SKAction",
        b"timingFunc",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"f"},
                    "arguments": {0: {"type": b"^v"}, 1: {"type": b"f"}},
                }
            }
        },
    )
    r(
        b"SKAction",
        b"timingFunction",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"f"},
                    "arguments": {0: {"type": b"^v"}, 1: {"type": b"f"}},
                }
            }
        },
    )
    r(b"SKAudioNode", b"autoplayLooped", {"retval": {"type": b"Z"}})
    r(b"SKAudioNode", b"isPositional", {"retval": {"type": b"Z"}})
    r(b"SKAudioNode", b"setAutoplayLooped:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKAudioNode", b"setPositional:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKCameraNode", b"containsNode:", {"retval": {"type": b"Z"}})
    r(b"SKConstraint", b"enabled", {"retval": {"type": b"Z"}})
    r(b"SKConstraint", b"setEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKEffectNode", b"setShouldCenterFilter:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKEffectNode", b"setShouldEnableEffects:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKEffectNode", b"setShouldRasterize:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKEffectNode", b"shouldCenterFilter", {"retval": {"type": b"Z"}})
    r(b"SKEffectNode", b"shouldEnableEffects", {"retval": {"type": b"Z"}})
    r(b"SKEffectNode", b"shouldRasterize", {"retval": {"type": b"Z"}})
    r(
        b"SKFieldNode",
        b"customFieldWithEvaluationBlock:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"SKFieldNode", b"direction", {"retval": {"type": b"%"}})
    r(b"SKFieldNode", b"isEnabled", {"retval": {"type": b"Z"}})
    r(b"SKFieldNode", b"isExclusive", {"retval": {"type": b"Z"}})
    r(
        b"SKFieldNode",
        b"linearGravityFieldWithVector:",
        {"arguments": {2: {"type": b"%"}}},
    )
    r(b"SKFieldNode", b"setDirection:", {"arguments": {2: {"type": b"%"}}})
    r(b"SKFieldNode", b"setEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKFieldNode", b"setExclusive:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKFieldNode", b"velocityFieldWithVector:", {"arguments": {2: {"type": b"%"}}})
    r(b"SKLightNode", b"isEnabled", {"retval": {"type": b"Z"}})
    r(b"SKLightNode", b"setEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SKMutableTexture",
        b"modifyPixelDataWithBlock:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {
                                "type": b"^v",
                                "type_modifier": "N",
                                "c_array_length_in_arg": 2,
                            },
                            2: {"type": b"Q"},
                        },
                    }
                }
            }
        },
    )
    r(b"SKNode", b"containsPoint:", {"retval": {"type": b"Z"}})
    r(
        b"SKNode",
        b"enumerateChildNodesWithName:usingBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"^Z", "type_modifier": "o"},
                        },
                    }
                }
            }
        },
    )
    r(b"SKNode", b"hasActions", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"inParentHierarchy:", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"intersectsNode:", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"isAccessibilityElement", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"isAccessibilityEnabled", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"isEqualToNode:", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"isHidden", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"isPaused", {"retval": {"type": b"Z"}})
    r(b"SKNode", b"isUserInteractionEnabled", {"retval": {"type": b"Z"}})
    r(
        b"SKNode",
        b"nodeWithFileNamed:securelyWithClasses:andError:",
        {"arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"SKNode",
        b"runAction:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"SKNode", b"setAccessibilityElement:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKNode", b"setAccessibilityEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKNode", b"setHidden:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKNode", b"setPaused:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKNode", b"setUserInteractionEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKPhysicsBody", b"affectedByGravity", {"retval": {"type": b"Z"}})
    r(b"SKPhysicsBody", b"allowsRotation", {"retval": {"type": b"Z"}})
    r(b"SKPhysicsBody", b"isDynamic", {"retval": {"type": b"Z"}})
    r(b"SKPhysicsBody", b"isResting", {"retval": {"type": b"Z"}})
    r(b"SKPhysicsBody", b"pinned", {"retval": {"type": b"Z"}})
    r(b"SKPhysicsBody", b"setAffectedByGravity:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKPhysicsBody", b"setAllowsRotation:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKPhysicsBody", b"setDynamic:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKPhysicsBody", b"setPinned:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKPhysicsBody", b"setResting:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SKPhysicsBody",
        b"setUsesPreciseCollisionDetection:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"SKPhysicsBody", b"usesPreciseCollisionDetection", {"retval": {"type": b"Z"}})
    r(
        b"SKPhysicsJointPin",
        b"setShouldEnableLimits:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"SKPhysicsJointPin", b"shouldEnableLimits", {"retval": {"type": b"Z"}})
    r(
        b"SKPhysicsJointSliding",
        b"setShouldEnableLimits:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"SKPhysicsJointSliding", b"shouldEnableLimits", {"retval": {"type": b"Z"}})
    r(
        b"SKPhysicsWorld",
        b"enumerateBodiesAlongRayStart:end:usingBlock:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"{CGPoint=dd}"},
                            3: {"type": b"{CGVector=dd}"},
                            4: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SKPhysicsWorld",
        b"enumerateBodiesAtPoint:usingBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"^Z", "type_modifier": "o"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SKPhysicsWorld",
        b"enumerateBodiesInRect:usingBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"^Z", "type_modifier": "o"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SKPhysicsWorld",
        b"sampleFieldsAt:",
        {"retval": {"type": b"%"}, "arguments": {2: {"type": b"%"}}},
    )
    r(b"SKRegion", b"containsPoint:", {"retval": {"type": b"Z"}})
    r(b"SKRenderer", b"ignoresSiblingOrder", {"retval": {"type": "Z"}})
    r(b"SKRenderer", b"setIgnoresSiblingOrder:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"SKRenderer",
        b"setShouldCullNonVisibleNodes:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"SKRenderer", b"setShowsDrawCount:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKRenderer", b"setShowsFields:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKRenderer", b"setShowsNodeCount:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKRenderer", b"setShowsPhysics:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKRenderer", b"setShowsQuadCount:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKRenderer", b"shouldCullNonVisibleNodes", {"retval": {"type": "Z"}})
    r(b"SKRenderer", b"showsDrawCount", {"retval": {"type": "Z"}})
    r(b"SKRenderer", b"showsFields", {"retval": {"type": "Z"}})
    r(b"SKRenderer", b"showsNodeCount", {"retval": {"type": "Z"}})
    r(b"SKRenderer", b"showsPhysics", {"retval": {"type": "Z"}})
    r(b"SKRenderer", b"showsQuadCount", {"retval": {"type": "Z"}})
    r(b"SKShapeNode", b"isAntialiased", {"retval": {"type": b"Z"}})
    r(b"SKShapeNode", b"setAntialiased:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SKShapeNode",
        b"shapeNodeWithPath:centered:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"SKShapeNode",
        b"shapeNodeWithPoints:count:",
        {"arguments": {2: {"type_modifier": b"n", "c_array_length_in_arg": 3}}},
    )
    r(
        b"SKShapeNode",
        b"shapeNodeWithSplinePoints:count:",
        {"arguments": {2: {"type_modifier": b"n", "c_array_length_in_arg": 3}}},
    )
    r(
        b"SKSpriteNode",
        b"spriteNodeWithImageNamed:normalMapped:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"SKTexture",
        b"preloadTextures:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"SKTexture",
        b"preloadWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"SKTexture", b"setUsesMipmaps:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SKTexture",
        b"textureNoiseWithSmoothness:size:grayscale:",
        {"arguments": {4: {"type": b"Z"}}},
    )
    r(
        b"SKTexture",
        b"textureWithData:size:flipped:",
        {"arguments": {4: {"type": b"Z"}}},
    )
    r(b"SKTexture", b"usesMipmaps", {"retval": {"type": b"Z"}})
    r(
        b"SKTextureAtlas",
        b"preloadTextureAtlases:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"SKTextureAtlas",
        b"preloadTextureAtlasesNamed:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SKTextureAtlas",
        b"preloadWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"SKTileDefinition", b"flipHorizontally", {"retval": {"type": "Z"}})
    r(b"SKTileDefinition", b"flipVertically", {"retval": {"type": "Z"}})
    r(b"SKTileDefinition", b"setFlipHorizontally:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKTileDefinition", b"setFlipVertically:", {"arguments": {2: {"type": "Z"}}})
    r(b"SKTileMapNode", b"enableAutomapping", {"retval": {"type": b"Z"}})
    r(b"SKTileMapNode", b"setEnableAutomapping:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKTransformNode", b"quaternion", {"retval": {"type": b"{_simd_quatf=}"}})
    r(
        b"SKTransformNode",
        b"rotationMatrix",
        {"retval": {"type": b"{_matrix_float3x3=?}"}},
    )
    r(
        b"SKTransformNode",
        b"setQuaternion:",
        {"arguments": {2: {"type": b"{_simd_quatf=}"}}},
    )
    r(
        b"SKTransformNode",
        b"setRotationMatrix:",
        {"arguments": {2: {"type": b"{_matrix_float3x3=?}"}}},
    )
    r(b"SKTransition", b"pausesIncomingScene", {"retval": {"type": b"Z"}})
    r(b"SKTransition", b"pausesOutgoingScene", {"retval": {"type": b"Z"}})
    r(b"SKTransition", b"setPausesIncomingScene:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKTransition", b"setPausesOutgoingScene:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SKUniform",
        b"initWithName:matrixFloat2x2:",
        {"arguments": {3: {"type": b"{_matrix_float2x2=?}"}}},
    )
    r(
        b"SKUniform",
        b"initWithName:matrixFloat3x3:",
        {"arguments": {3: {"type": b"{_matrix_float3x3=?}"}}},
    )
    r(
        b"SKUniform",
        b"initWithName:matrixFloat4x4:",
        {"arguments": {3: {"type": b"{_matrix_float4x4=?}"}}},
    )
    r(
        b"SKUniform",
        b"matrixFloat2x2Value",
        {"retval": {"type": b"{_matrix_float2x2=?}"}},
    )
    r(
        b"SKUniform",
        b"matrixFloat3x3Value",
        {"retval": {"type": b"{_matrix_float3x3=?}"}},
    )
    r(
        b"SKUniform",
        b"matrixFloat4x4Value",
        {"retval": {"type": b"{_matrix_float4x4=?}"}},
    )
    r(
        b"SKUniform",
        b"setMatrixFloat2x2Value:",
        {"arguments": {2: {"type": b"{_matrix_float2x2=?}"}}},
    )
    r(
        b"SKUniform",
        b"setMatrixFloat3x3Value:",
        {"arguments": {2: {"type": b"{_matrix_float3x3=?}"}}},
    )
    r(
        b"SKUniform",
        b"setMatrixFloat4x4Value:",
        {"arguments": {2: {"type": b"{_matrix_float4x4=?}"}}},
    )
    r(
        b"SKUniform",
        b"uniformWithName:matrixFloat2x2:",
        {"arguments": {3: {"type": b"{_matrix_float2x2=?}"}}},
    )
    r(
        b"SKUniform",
        b"uniformWithName:matrixFloat3x3:",
        {"arguments": {3: {"type": b"{_matrix_float3x3=?}"}}},
    )
    r(
        b"SKUniform",
        b"uniformWithName:matrixFloat4x4:",
        {"arguments": {3: {"type": b"{_matrix_float4x4=?}"}}},
    )
    r(b"SKView", b"allowsTransparency", {"retval": {"type": b"Z"}})
    r(b"SKView", b"disableDepthStencilBuffer", {"retval": {"type": "Z"}})
    r(b"SKView", b"ignoresSiblingOrder", {"retval": {"type": b"Z"}})
    r(b"SKView", b"isAsynchronous", {"retval": {"type": b"Z"}})
    r(b"SKView", b"isPaused", {"retval": {"type": b"Z"}})
    r(b"SKView", b"setAllowsTransparency:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setAsynchronous:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setDisableDepthStencilBuffer:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setIgnoresSiblingOrder:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setPaused:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShouldCullNonVisibleNodes:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShowsDrawCount:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShowsFPS:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShowsFields:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShowsNodeCount:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShowsPhysics:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"setShowsQuadCount:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SKView", b"shouldCullNonVisibleNodes", {"retval": {"type": b"Z"}})
    r(b"SKView", b"showsDrawCount", {"retval": {"type": b"Z"}})
    r(b"SKView", b"showsFPS", {"retval": {"type": b"Z"}})
    r(b"SKView", b"showsFields", {"retval": {"type": b"Z"}})
    r(b"SKView", b"showsNodeCount", {"retval": {"type": b"Z"}})
    r(b"SKView", b"showsPhysics", {"retval": {"type": b"Z"}})
    r(b"SKView", b"showsQuadCount", {"retval": {"type": b"Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {
    "SKTileAdjacencyRightEdge": "SKTileAdjacencyDown | SKTileAdjacencyLowerLeft | SKTileAdjacencyLeft | SKTileAdjacencyUpperLeft | SKTileAdjacencyUp",
    "SKTileAdjacencyUpperRightCorner": "SKTileAdjacencyUp | SKTileAdjacencyUpperRight | SKTileAdjacencyRight | SKTileAdjacencyLowerRight | SKTileAdjacencyDown | SKTileAdjacencyLeft | SKTileAdjacencyUpperLeft",
    "SKTileAdjacencyUpperRightEdge": "SKTileAdjacencyDown | SKTileAdjacencyLowerLeft | SKTileAdjacencyLeft",
    "SKTileAdjacencyLowerRightCorner": "SKTileAdjacencyUp | SKTileAdjacencyUpperRight | SKTileAdjacencyRight | SKTileAdjacencyLowerRight | SKTileAdjacencyDown | SKTileAdjacencyLowerLeft | SKTileAdjacencyLeft",
    "SKTileAdjacencyLowerRightEdge": "SKTileAdjacencyLeft | SKTileAdjacencyUpperLeft | SKTileAdjacencyUp",
    "SKTileAdjacencyDownEdge": "SKTileAdjacencyUp | SKTileAdjacencyUpperRight | SKTileAdjacencyRight | SKTileAdjacencyLeft | SKTileAdjacencyUpperLeft",
    "SKTileAdjacencyLeftEdge": "SKTileAdjacencyUp | SKTileAdjacencyUpperRight | SKTileAdjacencyRight | SKTileAdjacencyLowerRight | SKTileAdjacencyDown",
    "SKTileAdjacencyUpEdge": "SKTileAdjacencyRight | SKTileAdjacencyLowerRight | SKTileAdjacencyDown | SKTileAdjacencyLowerLeft | SKTileAdjacencyLeft",
    "SKTileAdjacencyLowerLeftEdge": "SKTileAdjacencyUp | SKTileAdjacencyUpperRight | SKTileAdjacencyRight",
    "SKTileAdjacencyUpperLeftCorner": "SKTileAdjacencyUp | SKTileAdjacencyUpperRight | SKTileAdjacencyRight | SKTileAdjacencyDown | SKTileAdjacencyLowerLeft | SKTileAdjacencyLeft | SKTileAdjacencyUpperLeft",
    "SKTileAdjacencyUpperLeftEdge": "SKTileAdjacencyRight | SKTileAdjacencyLowerRight | SKTileAdjacencyDown",
    "SKTileAdjacencyLowerLeftCorner": "SKTileAdjacencyUp | SKTileAdjacencyRight | SKTileAdjacencyLowerRight | SKTileAdjacencyDown | SKTileAdjacencyLowerLeft | SKTileAdjacencyLeft | SKTileAdjacencyUpperLeft",
}

# END OF FILE



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKPhysicsBody(TestCase):
    @min_os_level("10.9")
    def testMethods(self):
        self.assertIsInstance(SpriteKit.SKPhysicsBody, objc.objc_class)

        self.assertArgIsBOOL(SpriteKit.SKPhysicsBody.setDynamic_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsBody.isDynamic)
        self.assertArgIsBOOL(
            SpriteKit.SKPhysicsBody.setUsesPreciseCollisionDetection_, 0
        )
        self.assertResultIsBOOL(SpriteKit.SKPhysicsBody.usesPreciseCollisionDetection)
        self.assertArgIsBOOL(SpriteKit.SKPhysicsBody.setAllowsRotation_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsBody.allowsRotation)
        self.assertArgIsBOOL(SpriteKit.SKPhysicsBody.setResting_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsBody.isResting)
        self.assertArgIsBOOL(SpriteKit.SKPhysicsBody.setAffectedByGravity_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsBody.affectedByGravity)

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBOOL(SpriteKit.SKPhysicsBody.setPinned_, 0)
        self.assertResultIsBOOL(SpriteKit.SKPhysicsBody.pinned)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKFieldNode(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBOOL(SpriteKit.SKFieldNode.setEnabled_, 0)
        self.assertResultIsBOOL(SpriteKit.SKFieldNode.isEnabled)
        self.assertArgIsBOOL(SpriteKit.SKFieldNode.setExclusive_, 0)
        self.assertResultIsBOOL(SpriteKit.SKFieldNode.isExclusive)

        obj = SpriteKit.SKFieldNode.linearGravityFieldWithVector_((1, 2, 3))
        self.assertIsInstance(obj, SpriteKit.SKFieldNode)
        self.assertEqual(obj.direction(), (1, 2, 3))

        obj = SpriteKit.SKFieldNode.velocityFieldWithVector_((1, 2, 3))
        self.assertIsInstance(obj, SpriteKit.SKFieldNode)
        self.assertEqual(obj.direction(), (1, 2, 3))

        # FIXME
        # self.assertArgIsBlock(SpriteKit.SKFieldNode.customFieldWithEvaluationBlock_, 0,
        #        objc._C_VECTOR_FLOAT3 + objc._C_VECTOR_FLOAT3 + objc._C_FLOAT_VECTOR3 + objc._C_FLT + objc._C_FLT + objc._C_DBL)

        obj.setDirection_((9, 10, 11))
        self.assertEqual(obj.direction(), (9, 10, 11))



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKAttribute(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKAttributeTypeNone, 0)
        self.assertEqual(SpriteKit.SKAttributeTypeFloat, 1)
        self.assertEqual(SpriteKit.SKAttributeTypeVectorFloat2, 2)
        self.assertEqual(SpriteKit.SKAttributeTypeVectorFloat3, 3)
        self.assertEqual(SpriteKit.SKAttributeTypeVectorFloat4, 4)
        self.assertEqual(SpriteKit.SKAttributeTypeHalfFloat, 5)
        self.assertEqual(SpriteKit.SKAttributeTypeVectorHalfFloat2, 6)
        self.assertEqual(SpriteKit.SKAttributeTypeVectorHalfFloat3, 7)
        self.assertEqual(SpriteKit.SKAttributeTypeVectorHalfFloat4, 8)



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKNode(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKBlendModeAlpha, 0)
        self.assertEqual(SpriteKit.SKBlendModeAdd, 1)
        self.assertEqual(SpriteKit.SKBlendModeSubtract, 2)
        self.assertEqual(SpriteKit.SKBlendModeMultiply, 3)
        self.assertEqual(SpriteKit.SKBlendModeMultiplyX2, 4)
        self.assertEqual(SpriteKit.SKBlendModeScreen, 5)
        self.assertEqual(SpriteKit.SKBlendModeReplace, 6)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertIsInstance(SpriteKit.SKNode, objc.objc_class)

        self.assertArgIsBOOL(SpriteKit.SKNode.setPaused_, 0)
        self.assertResultIsBOOL(SpriteKit.SKNode.isPaused)
        self.assertArgIsBOOL(SpriteKit.SKNode.setHidden_, 0)
        self.assertResultIsBOOL(SpriteKit.SKNode.isHidden)
        self.assertArgIsBOOL(SpriteKit.SKNode.setUserInteractionEnabled_, 0)
        self.assertResultIsBOOL(SpriteKit.SKNode.isUserInteractionEnabled)
        self.assertResultIsBOOL(SpriteKit.SKNode.inParentHierarchy_)
        self.assertResultIsBOOL(SpriteKit.SKNode.hasActions)
        self.assertResultIsBOOL(SpriteKit.SKNode.containsPoint_)
        self.assertResultIsBOOL(SpriteKit.SKNode.intersectsNode_)

        self.assertArgIsBlock(
            SpriteKit.SKNode.enumerateChildNodesWithName_usingBlock_, 1, b"v@o^Z"
        )
        self.assertArgIsBlock(SpriteKit.SKNode.runAction_completion_, 1, b"v")

    @min_os_level("10.14")
    def testMethods10_14(self):
        self.assertArgIsOut(
            SpriteKit.SKNode.nodeWithFileNamed_securelyWithClasses_andError_, 2
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKTexture(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKTextureFilteringNearest, 0)
        self.assertEqual(SpriteKit.SKTextureFilteringLinear, 1)

    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertArgIsBOOL(SpriteKit.SKTexture.setUsesMipmaps_, 0)
        self.assertResultIsBOOL(SpriteKit.SKTexture.usesMipmaps)

        self.assertArgIsBlock(
            SpriteKit.SKTexture.preloadTextures_withCompletionHandler_, 1, b"v"
        )
        self.assertArgIsBlock(
            SpriteKit.SKTexture.preloadWithCompletionHandler_, 0, b"v"
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBOOL(SpriteKit.SKTexture.textureWithData_size_flipped_, 2)
        self.assertArgIsBOOL(
            SpriteKit.SKTexture.textureNoiseWithSmoothness_size_grayscale_, 2
        )



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
import SpriteKit


SKActionTimingFunction = objc._C_FLT + objc._C_FLT


class TestSKAction(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(SpriteKit.SKActionTimingLinear, 0)
        self.assertEqual(SpriteKit.SKActionTimingEaseIn, 1)
        self.assertEqual(SpriteKit.SKActionTimingEaseOut, 2)
        self.assertEqual(SpriteKit.SKActionTimingEaseInEaseOut, 3)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertIsInstance(SpriteKit.SKAction, objc.objc_class)

        self.assertArgIsBOOL(
            SpriteKit.SKAction.rotateToAngle_duration_shortestUnitArc_, 2
        )
        self.assertArgIsBOOL(
            SpriteKit.SKAction.animateWithTextures_timePerFrame_resize_restore_, 2
        )
        self.assertArgIsBOOL(
            SpriteKit.SKAction.animateWithTextures_timePerFrame_resize_restore_, 3
        )
        self.assertArgIsBOOL(
            SpriteKit.SKAction.playSoundFileNamed_waitForCompletion_, 1
        )
        self.assertArgIsBOOL(
            SpriteKit.SKAction.followPath_asOffset_orientToPath_duration_, 1
        )
        self.assertArgIsBOOL(
            SpriteKit.SKAction.followPath_asOffset_orientToPath_duration_, 2
        )
        self.assertArgIsSEL(SpriteKit.SKAction.performSelector_onTarget_, 0, b"v@:")

        self.assertArgIsBlock(
            SpriteKit.SKAction.customActionWithDuration_actionBlock_,
            1,
            b"v@" + objc._C_CGFloat,
        )

    @expectedFailure
    def testMethods_dispatch(self):
        self.fail("SpriteKit.SKAction.runBlock_queue_")
        self.fail("SpriteKit.SKAction.runBlock_")

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBOOL(
            SpriteKit.SKAction.followPath_asOffset_orientToPath_speed_, 1
        )
        self.assertArgIsBOOL(
            SpriteKit.SKAction.followPath_asOffset_orientToPath_speed_, 2
        )
        self.assertArgIsBOOL(SpriteKit.SKAction.setTexture_resize_, 1)
        self.assertResultIsBlock(
            SpriteKit.SKAction.timingFunction, SKActionTimingFunction
        )
        self.assertArgIsBlock(
            SpriteKit.SKAction.setTimingFunction_, 0, SKActionTimingFunction
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKRegion(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertResultIsBOOL(SpriteKit.SKRegion.containsPoint_)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SpriteKit


class TestSKEffectNode(TestCase):
    @min_os_level("10.9")
    def testMethods(self):
        self.assertArgIsBOOL(SpriteKit.SKEffectNode.setShouldCenterFilter_, 0)
        self.assertResultIsBOOL(SpriteKit.SKEffectNode.shouldCenterFilter)
        self.assertArgIsBOOL(SpriteKit.SKEffectNode.setShouldEnableEffects_, 0)
        self.assertResultIsBOOL(SpriteKit.SKEffectNode.shouldEnableEffects)
        self.assertArgIsBOOL(SpriteKit.SKEffectNode.setShouldRasterize_, 0)
        self.assertResultIsBOOL(SpriteKit.SKEffectNode.shouldRasterize)
